#[non_exhaustive]pub struct ScucActiveReserveZone {Show 14 fields
pub id: ComponentId,
pub buses: Vec<ComponentId>,
pub regulation_up_requirement_fraction: f64,
pub regulation_down_requirement_fraction: f64,
pub synchronized_requirement_fraction: f64,
pub nonsynchronized_requirement_fraction: f64,
pub ramping_up_requirement: Vec<f64>,
pub ramping_down_requirement: Vec<f64>,
pub regulation_up_violation_cost: f64,
pub regulation_down_violation_cost: f64,
pub synchronized_violation_cost: f64,
pub nonsynchronized_violation_cost: f64,
pub ramping_up_violation_cost: f64,
pub ramping_down_violation_cost: f64,
}Expand description
Active reserve requirements and violation costs for one zone.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: ComponentIdbuses: Vec<ComponentId>Buses assigned to this zone by stable source identity.
regulation_up_requirement_fraction: f64regulation_down_requirement_fraction: f64synchronized_requirement_fraction: f64nonsynchronized_requirement_fraction: f64ramping_up_requirement: Vec<f64>ramping_down_requirement: Vec<f64>regulation_up_violation_cost: f64regulation_down_violation_cost: f64synchronized_violation_cost: f64nonsynchronized_violation_cost: f64ramping_up_violation_cost: f64ramping_down_violation_cost: f64Trait Implementations
Sourceimpl Clone for ScucActiveReserveZone
impl Clone for ScucActiveReserveZone
Sourcefn clone(&self) -> ScucActiveReserveZone
fn clone(&self) -> ScucActiveReserveZone
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScucActiveReserveZone
impl Debug for ScucActiveReserveZone
Sourceimpl<'de> Deserialize<'de> for ScucActiveReserveZone
impl<'de> Deserialize<'de> for ScucActiveReserveZone
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScucActiveReserveZone
impl JsonSchema for ScucActiveReserveZone
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ScucActiveReserveZone
impl PartialEq for ScucActiveReserveZone
Sourcefn eq(&self, other: &ScucActiveReserveZone) -> bool
fn eq(&self, other: &ScucActiveReserveZone) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ScucActiveReserveZone
impl Serialize for ScucActiveReserveZone
impl StructuralPartialEq for ScucActiveReserveZone