#[non_exhaustive]pub struct ScucDevice {Show 17 fields
pub id: ComponentId,
pub kind: ScucDeviceKind,
pub on_cost: f64,
pub startup_cost: f64,
pub startup_cost_adjustments: Vec<ScucStartupCostAdjustment>,
pub shutdown_cost: f64,
pub startup_limits: Vec<ScucStartupLimit>,
pub energy_upper_bounds: Vec<ScucEnergyRequirement>,
pub energy_lower_bounds: Vec<ScucEnergyRequirement>,
pub minimum_up_time: f64,
pub minimum_down_time: f64,
pub ramp_limits: ScucRampLimits,
pub reserve_limits: ScucReserveLimits,
pub initial_on_status: bool,
pub initial_commitment: ScucInitialCommitment,
pub reactive_capability: ScucReactiveCapability,
pub periods: Vec<ScucDevicePeriod>,
}Expand description
Scheduling and cost inputs for one simple dispatchable device.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: ComponentIdThe corresponding generator or load in the balanced network.
kind: ScucDeviceKindon_cost: f64Fixed operating cost in dollars.
startup_cost: f64Base startup cost in dollars.
startup_cost_adjustments: Vec<ScucStartupCostAdjustment>shutdown_cost: f64Shutdown cost in dollars.
startup_limits: Vec<ScucStartupLimit>energy_upper_bounds: Vec<ScucEnergyRequirement>energy_lower_bounds: Vec<ScucEnergyRequirement>minimum_up_time: f64Minimum in service time after startup, in hours.
minimum_down_time: f64Minimum out of service time after shutdown, in hours.
ramp_limits: ScucRampLimitsreserve_limits: ScucReserveLimitsinitial_on_status: boolCommitment immediately before the first interval.
initial_commitment: ScucInitialCommitmentreactive_capability: ScucReactiveCapabilityperiods: Vec<ScucDevicePeriod>Values in the same chronological order as ScucInputs::interval_durations.