#[non_exhaustive]pub struct ScucDevicePeriod {
pub on_status_min: bool,
pub on_status_max: bool,
pub active_power_min: f64,
pub active_power_max: f64,
pub reactive_power_min: f64,
pub reactive_power_max: f64,
pub energy_cost_blocks: Vec<ScucEnergyCostBlock>,
pub reserve_costs: ScucReserveCosts,
}Expand description
Time varying inputs for one dispatchable device and one interval.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.on_status_min: boolon_status_max: boolactive_power_min: f64Active power lower bound in per unit on the instance system base.
active_power_max: f64Active power upper bound in per unit on the instance system base.
reactive_power_min: f64Reactive power lower bound in per unit on the instance system base.
reactive_power_max: f64Reactive power upper bound in per unit on the instance system base.
energy_cost_blocks: Vec<ScucEnergyCostBlock>reserve_costs: ScucReserveCostsTrait Implementations
Sourceimpl Clone for ScucDevicePeriod
impl Clone for ScucDevicePeriod
Sourcefn clone(&self) -> ScucDevicePeriod
fn clone(&self) -> ScucDevicePeriod
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScucDevicePeriod
impl Debug for ScucDevicePeriod
Sourceimpl<'de> Deserialize<'de> for ScucDevicePeriod
impl<'de> Deserialize<'de> for ScucDevicePeriod
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScucDevicePeriod
impl JsonSchema for ScucDevicePeriod
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ScucDevicePeriod
impl PartialEq for ScucDevicePeriod
Sourcefn eq(&self, other: &ScucDevicePeriod) -> bool
fn eq(&self, other: &ScucDevicePeriod) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ScucDevicePeriod
impl Serialize for ScucDevicePeriod
impl StructuralPartialEq for ScucDevicePeriod