#[non_exhaustive]pub struct ScucEnergyRequirement {
pub start_time: f64,
pub end_time: f64,
pub energy: f64,
}Expand description
An energy requirement over one time window.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start_time: f64Window start, in hours from the beginning of the horizon.
end_time: f64Window end, in hours from the beginning of the horizon.
energy: f64Energy bound in per unit, as defined by the GO Challenge 3 data model.