#[non_exhaustive]pub struct ScucInitialCommitment {
pub accumulated_up_time: f64,
pub accumulated_down_time: f64,
}Expand description
Initial commitment duration data not carried by the electrical network.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.accumulated_up_time: f64Accumulated in service time before the first interval, in hours.
accumulated_down_time: f64Accumulated out of service time before the first interval, in hours.