#[non_exhaustive]pub struct ScucRampLimits {
pub up: f64,
pub down: f64,
pub startup: f64,
pub shutdown: f64,
}Expand description
Active power ramp limits for one dispatchable device, in per unit per hour.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.up: f64down: f64startup: f64shutdown: f64Trait Implementations
Sourceimpl Clone for ScucRampLimits
impl Clone for ScucRampLimits
Sourcefn clone(&self) -> ScucRampLimits
fn clone(&self) -> ScucRampLimits
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ScucRampLimits
Sourceimpl Debug for ScucRampLimits
impl Debug for ScucRampLimits
Sourceimpl<'de> Deserialize<'de> for ScucRampLimits
impl<'de> Deserialize<'de> for ScucRampLimits
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScucRampLimits
impl JsonSchema for ScucRampLimits
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ScucRampLimits
impl PartialEq for ScucRampLimits
Sourcefn eq(&self, other: &ScucRampLimits) -> bool
fn eq(&self, other: &ScucRampLimits) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ScucRampLimits
impl Serialize for ScucRampLimits
impl StructuralPartialEq for ScucRampLimits