#[non_exhaustive]pub struct ScucReactiveReserveZone {
pub id: ComponentId,
pub buses: Vec<ComponentId>,
pub reactive_up_requirement: Vec<f64>,
pub reactive_down_requirement: Vec<f64>,
pub reactive_up_violation_cost: f64,
pub reactive_down_violation_cost: f64,
}Expand description
Reactive reserve requirements and violation costs for one zone.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: ComponentIdbuses: Vec<ComponentId>Buses assigned to this zone by stable source identity.
reactive_up_requirement: Vec<f64>reactive_down_requirement: Vec<f64>reactive_up_violation_cost: f64reactive_down_violation_cost: f64Trait Implementations
Sourceimpl Clone for ScucReactiveReserveZone
impl Clone for ScucReactiveReserveZone
Sourcefn clone(&self) -> ScucReactiveReserveZone
fn clone(&self) -> ScucReactiveReserveZone
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScucReactiveReserveZone
impl Debug for ScucReactiveReserveZone
Sourceimpl<'de> Deserialize<'de> for ScucReactiveReserveZone
impl<'de> Deserialize<'de> for ScucReactiveReserveZone
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScucReactiveReserveZone
impl JsonSchema for ScucReactiveReserveZone
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ScucReactiveReserveZone
impl PartialEq for ScucReactiveReserveZone
Sourcefn eq(&self, other: &ScucReactiveReserveZone) -> bool
fn eq(&self, other: &ScucReactiveReserveZone) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ScucReactiveReserveZone
impl Serialize for ScucReactiveReserveZone
impl StructuralPartialEq for ScucReactiveReserveZone