#[non_exhaustive]pub struct ScucReserveCosts {
pub regulation_up: f64,
pub regulation_down: f64,
pub synchronized: f64,
pub nonsynchronized: f64,
pub ramping_up_online: f64,
pub ramping_down_online: f64,
pub ramping_up_offline: f64,
pub ramping_down_offline: f64,
pub reactive_up: f64,
pub reactive_down: f64,
}Expand description
Reserve costs for one device and one interval, in $/(p.u. h).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.regulation_up: f64regulation_down: f64synchronized: f64nonsynchronized: f64ramping_up_online: f64ramping_down_online: f64ramping_up_offline: f64ramping_down_offline: f64reactive_up: f64reactive_down: f64Trait Implementations
Sourceimpl Clone for ScucReserveCosts
impl Clone for ScucReserveCosts
Sourcefn clone(&self) -> ScucReserveCosts
fn clone(&self) -> ScucReserveCosts
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ScucReserveCosts
Sourceimpl Debug for ScucReserveCosts
impl Debug for ScucReserveCosts
Sourceimpl<'de> Deserialize<'de> for ScucReserveCosts
impl<'de> Deserialize<'de> for ScucReserveCosts
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScucReserveCosts
impl JsonSchema for ScucReserveCosts
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ScucReserveCosts
impl PartialEq for ScucReserveCosts
Sourcefn eq(&self, other: &ScucReserveCosts) -> bool
fn eq(&self, other: &ScucReserveCosts) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ScucReserveCosts
impl Serialize for ScucReserveCosts
impl StructuralPartialEq for ScucReserveCosts