#[non_exhaustive]pub struct ScucShunt {
pub id: ComponentId,
pub conductance_per_step: f64,
pub susceptance_per_step: f64,
pub step_min: i64,
pub step_max: i64,
pub initial_step: i64,
}Expand description
Discrete step limits for one shunt in the balanced network.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: ComponentIdconductance_per_step: f64Conductance added by one step, in per unit on the instance system base.
susceptance_per_step: f64Susceptance added by one step, in per unit on the instance system base.
step_min: i64step_max: i64initial_step: i64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ScucShunt
impl<'de> Deserialize<'de> for ScucShunt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScucShunt
impl JsonSchema for ScucShunt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ScucShunt