#[non_exhaustive]pub struct ScucStartupLimit {
pub start_time: f64,
pub end_time: f64,
pub maximum_startups: u64,
}Expand description
A limit on how many times one device can start within a time window.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start_time: f64Window start, in hours from the beginning of the horizon.
end_time: f64Window end, in hours from the beginning of the horizon.
maximum_startups: u64Trait Implementations
Sourceimpl Clone for ScucStartupLimit
impl Clone for ScucStartupLimit
Sourcefn clone(&self) -> ScucStartupLimit
fn clone(&self) -> ScucStartupLimit
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ScucStartupLimit
Sourceimpl Debug for ScucStartupLimit
impl Debug for ScucStartupLimit
Sourceimpl<'de> Deserialize<'de> for ScucStartupLimit
impl<'de> Deserialize<'de> for ScucStartupLimit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScucStartupLimit
impl JsonSchema for ScucStartupLimit
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ScucStartupLimit
impl PartialEq for ScucStartupLimit
Sourcefn eq(&self, other: &ScucStartupLimit) -> bool
fn eq(&self, other: &ScucStartupLimit) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ScucStartupLimit
impl Serialize for ScucStartupLimit
impl StructuralPartialEq for ScucStartupLimit