#[non_exhaustive]pub struct ScucTransformerControl {
pub id: ComponentId,
pub tap_ratio_min: f64,
pub tap_ratio_max: f64,
pub phase_shift_min: f64,
pub phase_shift_max: f64,
}Expand description
Tap ratio and phase shift bounds for one two winding transformer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: ComponentIdtap_ratio_min: f64Off nominal tap ratio lower bound in per unit.
tap_ratio_max: f64Off nominal tap ratio upper bound in per unit.
phase_shift_min: f64Phase shift bounds in radians.
phase_shift_max: f64Trait Implementations
Sourceimpl Clone for ScucTransformerControl
impl Clone for ScucTransformerControl
Sourcefn clone(&self) -> ScucTransformerControl
fn clone(&self) -> ScucTransformerControl
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScucTransformerControl
impl Debug for ScucTransformerControl
Sourceimpl<'de> Deserialize<'de> for ScucTransformerControl
impl<'de> Deserialize<'de> for ScucTransformerControl
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScucTransformerControl
impl JsonSchema for ScucTransformerControl
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ScucTransformerControl
impl PartialEq for ScucTransformerControl
Sourcefn eq(&self, other: &ScucTransformerControl) -> bool
fn eq(&self, other: &ScucTransformerControl) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ScucTransformerControl
impl Serialize for ScucTransformerControl
impl StructuralPartialEq for ScucTransformerControl